@@ -2,7 +2,7 @@ use super::*;
 
 /// Simple implementor of FeroxFilter; used to filter out responses based on the number of lines
 /// in a Response body; specified using -N|--filter-lines
-#[derive(Default, Debug, PartialEq)]
+#[derive(Default, Debug, PartialEq, Serialize, Deserialize)]
 pub struct LinesFilter {
     /// Number of lines in a Response's body that should be filtered
     pub line_count: usize,
